Mixed-Up Code Questions
------------------------

.. selectquestion:: dictionaries_mixedupcode_question10_1_sq
   :fromid: dictionaries_mixedupcode_question10_1, dictionaries_mixedupcode_question10_1_ac
   :toggle: 
  
.. selectquestion:: dictionaries_mixedupcode_question10_2_sq
   :fromid: dictionaries_mixedupcode_question10_2, dictionaries_mixedupcode_question10_2_ac
   :toggle: 

.. selectquestion:: dictionaries_mixedupcode_question10_3_sq
   :fromid: dictionaries_mixedupcode_question10_3, dictionaries_mixedupcode_question10_3_ac
   :toggle: 

.. selectquestion:: dictionaries_mixedupcode_question10_4_sq
   :fromid: dictionaries_mixedupcode_question10_4, dictionaries_mixedupcode_question10_4_ac
   :toggle: 

.. selectquestion:: dictionaries_mixedupcode_question10_5_sq
   :fromid: dictionaries_mixedupcode_question10_5, dictionaries_mixedupcode_question10_5_ac
   :toggle: 

.. selectquestion:: dictionaries_mixedupcode_question10_6_sq
   :fromid: dictionaries_mixedupcode_question10_6, dictionaries_mixedupcode_question10_6_ac
   :toggle: 

.. selectquestion:: dictionaries_mixedupcode_question10_7_sq
   :fromid: dictionaries_mixedupcode_question10_7, dictionaries_mixedupcode_question10_7_ac
   :toggle: 

.. selectquestion:: dictionaries_mixedupcode_question10_8_sq
   :fromid: dictionaries_mixedupcode_question10_8, dictionaries_mixedupcode_question10_8_ac
   :toggle: 

.. selectquestion:: dictionaries_mixedupcode_question10_9_sq
   :fromid: dictionaries_mixedupcode_question10_9, dictionaries_mixedupcode_question10_9_ac
   :toggle: 

.. selectquestion:: dictionaries_mixedupcode_question10_10_sq
   :fromid: dictionaries_mixedupcode_question10_10, dictionaries_mixedupcode_question10_10_ac
   :toggle: 